@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class PREFERENCES_OT_addon_disable(bpy_types.Operator):
     bl_idname = None
@@ -66,6 +64,24 @@ class PREFERENCES_OT_addon_disable(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -126,6 +142,12 @@ class PREFERENCES_OT_addon_disable(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -218,6 +240,24 @@ class PREFERENCES_OT_addon_enable(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -278,6 +318,12 @@ class PREFERENCES_OT_addon_enable(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -373,6 +419,24 @@ class PREFERENCES_OT_addon_expand(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -433,6 +497,12 @@ class PREFERENCES_OT_addon_expand(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -525,6 +595,24 @@ class PREFERENCES_OT_addon_install(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -591,6 +679,12 @@ class PREFERENCES_OT_addon_install(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -683,6 +777,24 @@ class PREFERENCES_OT_addon_refresh(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -743,6 +855,12 @@ class PREFERENCES_OT_addon_refresh(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -841,6 +959,24 @@ class PREFERENCES_OT_addon_remove(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -913,6 +1049,12 @@ class PREFERENCES_OT_addon_remove(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1008,6 +1150,24 @@ class PREFERENCES_OT_addon_show(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1068,6 +1228,12 @@ class PREFERENCES_OT_addon_show(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1160,6 +1326,24 @@ class PREFERENCES_OT_app_template_install(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -1226,6 +1410,12 @@ class PREFERENCES_OT_app_template_install(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1318,6 +1508,24 @@ class PREFERENCES_OT_copy_prev(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1384,6 +1592,12 @@ class PREFERENCES_OT_copy_prev(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1482,6 +1696,24 @@ class PREFERENCES_OT_keyconfig_activate(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1542,6 +1774,12 @@ class PREFERENCES_OT_keyconfig_activate(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1634,6 +1872,24 @@ class PREFERENCES_OT_keyconfig_export(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -1700,6 +1956,12 @@ class PREFERENCES_OT_keyconfig_export(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1792,6 +2054,24 @@ class PREFERENCES_OT_keyconfig_import(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -1858,6 +2138,12 @@ class PREFERENCES_OT_keyconfig_import(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1950,6 +2236,24 @@ class PREFERENCES_OT_keyconfig_remove(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2016,6 +2320,12 @@ class PREFERENCES_OT_keyconfig_remove(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2108,6 +2418,24 @@ class PREFERENCES_OT_keyconfig_test(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2168,6 +2496,12 @@ class PREFERENCES_OT_keyconfig_test(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2260,6 +2594,24 @@ class PREFERENCES_OT_keyitem_add(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2320,6 +2672,12 @@ class PREFERENCES_OT_keyitem_add(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2412,6 +2770,24 @@ class PREFERENCES_OT_keyitem_remove(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2478,6 +2854,12 @@ class PREFERENCES_OT_keyitem_remove(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2570,6 +2952,24 @@ class PREFERENCES_OT_keyitem_restore(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2636,6 +3036,12 @@ class PREFERENCES_OT_keyitem_restore(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2728,6 +3134,24 @@ class PREFERENCES_OT_keymap_restore(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2788,6 +3212,12 @@ class PREFERENCES_OT_keymap_restore(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2880,6 +3310,24 @@ class PREFERENCES_OT_studiolight_copy_settings(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2940,6 +3388,12 @@ class PREFERENCES_OT_studiolight_copy_settings(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3032,6 +3486,24 @@ class PREFERENCES_OT_studiolight_install(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -3098,6 +3570,12 @@ class PREFERENCES_OT_studiolight_install(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3199,6 +3677,24 @@ class PREFERENCES_OT_studiolight_new(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -3265,6 +3761,12 @@ class PREFERENCES_OT_studiolight_new(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3360,6 +3862,24 @@ class PREFERENCES_OT_studiolight_show(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3420,6 +3940,12 @@ class PREFERENCES_OT_studiolight_show(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3512,6 +4038,24 @@ class PREFERENCES_OT_studiolight_uninstall(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3572,6 +4116,12 @@ class PREFERENCES_OT_studiolight_uninstall(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3664,6 +4214,24 @@ class PREFERENCES_OT_theme_install(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -3730,6 +4298,12 @@ class PREFERENCES_OT_theme_install(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
