@@ -3,8 +3,6 @@ import typing
 import bpy_types
 import bl_ui.utils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class RENDER_MT_framerate_presets(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
@@ -82,6 +80,24 @@ class RENDER_MT_framerate_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -281,6 +297,24 @@ class RENDER_PT_ffmpeg_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -397,8 +431,8 @@ class RENDER_PT_ffmpeg_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
         pass
 
 
-class RENDER_PT_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
-                        bpy_types._GenericUI):
+class RENDER_PT_format_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
+                               bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -483,6 +517,24 @@ class RENDER_PT_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -655,6 +707,24 @@ class RENDER_UL_renderviews(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -781,204 +851,6 @@ class RenderOutputButtonsPanel:
         pass
 
 
-class RENDER_PT_dimensions(RenderOutputButtonsPanel, bpy_types.Panel,
-                           bpy_types._GenericUI):
-    COMPAT_ENGINES = None
-    ''' '''
-
-    bl_context = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass_py(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_framerate(self, layout, rd):
-        ''' 
-
-        '''
-        pass
-
-    def draw_header_preset(self, _context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_overridable_library(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def pop(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_overridable_library_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
 class RENDER_PT_encoding(RenderOutputButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
     COMPAT_ENGINES = None
@@ -1062,6 +934,24 @@ class RENDER_PT_encoding(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1251,6 +1141,24 @@ class RENDER_PT_encoding_audio(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1446,6 +1354,24 @@ class RENDER_PT_encoding_video(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1561,8 +1487,8 @@ class RENDER_PT_encoding_video(RenderOutputButtonsPanel, bpy_types.Panel,
         pass
 
 
-class RENDER_PT_frame_remapping(RenderOutputButtonsPanel, bpy_types.Panel,
-                                bpy_types._GenericUI):
+class RENDER_PT_format(RenderOutputButtonsPanel, bpy_types.Panel,
+                       bpy_types._GenericUI):
     COMPAT_ENGINES = None
     ''' '''
 
@@ -1572,10 +1498,220 @@ class RENDER_PT_frame_remapping(RenderOutputButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
-    bl_options = None
+    bl_region_type = None
     ''' '''
 
-    bl_parent_id = None
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_framerate(self, layout, rd):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class RENDER_PT_frame_range(RenderOutputButtonsPanel, bpy_types.Panel,
+                            bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
     ''' '''
 
     bl_region_type = None
@@ -1638,6 +1774,24 @@ class RENDER_PT_frame_remapping(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1824,6 +1978,24 @@ class RENDER_PT_output(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2013,6 +2185,24 @@ class RENDER_PT_output_views(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2202,6 +2392,24 @@ class RENDER_PT_post_processing(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2391,6 +2599,24 @@ class RENDER_PT_stamp(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2589,6 +2815,24 @@ class RENDER_PT_stamp_burn(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2787,6 +3031,24 @@ class RENDER_PT_stamp_note(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2982,6 +3244,234 @@ class RENDER_PT_stereoscopy(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class RENDER_PT_time_stretching(RenderOutputButtonsPanel, bpy_types.Panel,
+                                bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_parent_id = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
