@@ -107,6 +107,24 @@ class VIEW3D_MT_tools_projectpaint_clone(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -714,7 +732,7 @@ def brush_basic_gpencil_paint_settings(layout, context, brush, compact):
     pass
 
 
-def brush_basic_gpencil_sculpt_settings(layout, context, brush, compact):
+def brush_basic_gpencil_sculpt_settings(layout, _context, brush, compact):
     ''' 
 
     '''
