@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class TEXT_HT_footer(bpy_types.Header, bpy_types._GenericUI):
     bl_region_type = None
@@ -66,6 +64,24 @@ class TEXT_HT_footer(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -233,6 +249,24 @@ class TEXT_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -412,6 +446,24 @@ class TEXT_MT_context_menu(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -598,6 +650,24 @@ class TEXT_MT_edit(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -790,6 +860,24 @@ class TEXT_MT_edit_to3d(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -979,6 +1067,24 @@ class TEXT_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1165,6 +1271,24 @@ class TEXT_MT_format(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1351,6 +1475,24 @@ class TEXT_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1537,6 +1679,24 @@ class TEXT_MT_templates(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1723,6 +1883,24 @@ class TEXT_MT_templates_osl(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1909,6 +2087,24 @@ class TEXT_MT_templates_py(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2095,6 +2291,24 @@ class TEXT_MT_text(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2281,6 +2495,24 @@ class TEXT_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2467,6 +2699,24 @@ class TEXT_MT_view_navigation(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2650,6 +2900,24 @@ class TEXT_PT_find(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -2826,6 +3094,24 @@ class TEXT_PT_properties(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
