@@ -68,7 +68,7 @@ class IMAGE_PT_tools_active(
         '''
         pass
 
-    def draw_active_tool_header(self, context, layout, show_tool_name,
+    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                 tool_key):
         ''' 
 
@@ -111,6 +111,24 @@ class IMAGE_PT_tools_active(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -313,7 +331,7 @@ class NODE_PT_tools_active(bl_ui.space_toolsystem_common.ToolSelectPanelHelper,
         '''
         pass
 
-    def draw_active_tool_header(self, context, layout, show_tool_name,
+    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                 tool_key):
         ''' 
 
@@ -356,6 +374,24 @@ class NODE_PT_tools_active(bl_ui.space_toolsystem_common.ToolSelectPanelHelper,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -559,7 +595,7 @@ class SEQUENCER_PT_tools_active(
         '''
         pass
 
-    def draw_active_tool_header(self, context, layout, show_tool_name,
+    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                 tool_key):
         ''' 
 
@@ -602,6 +638,24 @@ class SEQUENCER_PT_tools_active(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -805,7 +859,7 @@ class VIEW3D_PT_tools_active(
         '''
         pass
 
-    def draw_active_tool_header(self, context, layout, show_tool_name,
+    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                 tool_key):
         ''' 
 
@@ -848,6 +902,24 @@ class VIEW3D_PT_tools_active(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1128,6 +1200,9 @@ class _defs_gpencil_edit:
     extrude = None
     ''' '''
 
+    interpolate = None
+    ''' '''
+
     lasso_select = None
     ''' '''
 
@@ -1172,6 +1247,9 @@ class _defs_gpencil_paint:
     eyedropper = None
     ''' '''
 
+    interpolate = None
+    ''' '''
+
     line = None
     ''' '''
 
@@ -1184,7 +1262,7 @@ class _defs_gpencil_paint:
         '''
         pass
 
-    def gpencil_primitive_toolbar(self, context, layout, tool, props):
+    def gpencil_primitive_toolbar(self, context, layout, _tool, props):
         ''' 
 
         '''
@@ -1374,9 +1452,24 @@ class _defs_sequencer_generic:
     blade = None
     ''' '''
 
+    cursor = None
+    ''' '''
+
+    rotate = None
+    ''' '''
+
     sample = None
     ''' '''
 
+    scale = None
+    ''' '''
+
+    transform = None
+    ''' '''
+
+    translate = None
+    ''' '''
+
 
 class _defs_sequencer_select:
     box = None
