@@ -210,25 +210,21 @@ def word_wrap(fontid: int, wrap_width: int):
 
 
 CLIPPING = None
-''' constant value 2
-'''
-
-KERNING_DEFAULT = None
-''' constant value 8
+''' Constant value 2
 '''
 
 MONOCHROME = None
-''' constant value 128
+''' Constant value 128
 '''
 
 ROTATION = None
-''' constant value 1
+''' Constant value 1
 '''
 
 SHADOW = None
-''' constant value 4
+''' Constant value 4
 '''
 
 WORD_WRAP = None
-''' constant value 64
+''' Constant value 64
 '''
