@@ -4,15 +4,13 @@ import bpy.types
 
 from . import types
 from . import ops
-from . import app
 from . import utils
-from . import props
+from . import app
+from . import context
 from . import msgbus
+from . import props
 from . import path
 
-GenericType = typing.TypeVar("GenericType")
-context: 'bpy.types.Context' = None
-
 data: 'bpy.types.BlendData' = None
 ''' Access to Blender's internal data
 '''
