@@ -1,25 +1,24 @@
 import sys
 import typing
+from . import handlers
 from . import timers
 from . import translations
-from . import handlers
 from . import icons
 
-GenericType = typing.TypeVar("GenericType")
 alembic = None
-''' constant value bpy.app.alembic(supported=True, version=(1, 7, 16), version_string=' 1, 7, 16')
+''' Constant value bpy.app.alembic(supported=True, version=(1, 7, 16), version_string=' 1, 7, 16')
 '''
 
 autoexec_fail = None
-''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 autoexec_fail_message = None
-''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 autoexec_fail_quiet = None
-''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 background = None
@@ -30,10 +29,6 @@ binary_path = None
 ''' The location of Blender's executable, useful for utilities that open new instances
 '''
 
-binary_path_python = None
-''' String, the path to the python executable (read-only). Deprecated! Use ``sys.executable`` instead.
-'''
-
 build_branch = None
 ''' The branch this blender instance was built from
 '''
@@ -71,7 +66,7 @@ build_linkflags = None
 '''
 
 build_options = None
-''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, coreaudio=False, jack=True, pulseaudio=True, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True)
+''' Constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, coreaudio=False, jack=True, pulseaudio=True, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True)
 '''
 
 build_platform = None
@@ -163,23 +158,23 @@ factory_startup = None
 '''
 
 ffmpeg = None
-''' constant value bpy.app.ffmpeg(supported=True, avcodec_version=(58, 54, 100), avcodec_version_string='58, 54, 100', avdevice_version=(58, 8, 100), avdevice_version_string='58, 8, 100', avformat_version=(58, 29, 100), avformat_version_string='58, 29, 100', avutil_version=(56, 31, 100), avutil_version_string='56, 31, 100', swscale_version=(5, 5, 100), swscale_version_string=' 5, 5, 100')
+''' Constant value bpy.app.ffmpeg(supported=True, avcodec_version=(58, 134, 100), avcodec_version_string='58, 134, 100', avdevice_version=(58, 13, 100), avdevice_version_string='58, 13, 100', avformat_version=(58, 76, 100), avformat_version_string='58, 76, 100', avutil_version=(56, 70, 100), avutil_version_string='56, 70, 100', swscale_version=(5, 9, 100), swscale_version_string=' 5, 9, 100')
 '''
 
 ocio = None
-''' constant value bpy.app.ocio(supported=True, version=(2, 0, 0), version_string=' 2, 0, 0')
+''' Constant value bpy.app.ocio(supported=True, version=(2, 0, 0), version_string=' 2, 0, 0')
 '''
 
 oiio = None
-''' constant value bpy.app.oiio(supported=True, version=(2, 1, 15), version_string=' 2, 1, 15')
+''' Constant value bpy.app.oiio(supported=True, version=(2, 2, 15), version_string=' 2, 2, 15')
 '''
 
 opensubdiv = None
-''' constant value bpy.app.opensubdiv(supported=True, version=(0, 0, 0), version_string=' 0, 0, 0')
+''' Constant value bpy.app.opensubdiv(supported=True, version=(0, 0, 0), version_string=' 0, 0, 0')
 '''
 
 openvdb = None
-''' constant value bpy.app.openvdb(supported=True, version=(8, 0, 0), version_string=' 8, 0, 0')
+''' Constant value bpy.app.openvdb(supported=True, version=(8, 0, 0), version_string=' 8, 0, 0')
 '''
 
 render_icon_size = None
@@ -191,7 +186,7 @@ render_preview_size = None
 '''
 
 sdl = None
-''' constant value bpy.app.sdl(supported=True, version=(0, 0, 0), version_string='Unknown', available=False)
+''' Constant value bpy.app.sdl(supported=True, version=(0, 0, 0), version_string='Unknown', available=False)
 '''
 
 tempdir = None
@@ -199,7 +194,7 @@ tempdir = None
 '''
 
 usd = None
-''' constant value bpy.app.usd(supported=True, version=(0, 21, 2), version_string=' 0, 21, 2')
+''' Constant value bpy.app.usd(supported=True, version=(0, 21, 2), version_string=' 0, 21, 2')
 '''
 
 use_event_simulate = None
@@ -223,7 +218,7 @@ version_cycle = None
 '''
 
 version_file = None
-''' The blend file version, compatible with ``bpy.data.version``
+''' The Blender version, as a tuple, last used to save a .blend file, compatible with bpy.data.version . This value should be used for handling compatibility changes between Blender versions
 '''
 
 version_string = None
