@@ -6,6 +6,7 @@ import bpy.types
 def edge_face_count(mesh) -> list:
     ''' 
 
+    :rtype: list
     :return: list face users for each item in mesh.edges.
     '''
 
@@ -15,6 +16,7 @@ def edge_face_count(mesh) -> list:
 def edge_face_count_dict(mesh) -> dict:
     ''' 
 
+    :rtype: dict
     :return: dict of edge keys with their value set to the number of faces using each edge.
     '''
 
@@ -34,6 +36,7 @@ def mesh_linked_triangles(mesh: 'bpy.types.Mesh') -> list:
 
     :param mesh: the mesh used to group with.
     :type mesh: 'bpy.types.Mesh'
+    :rtype: list
     :return: lists of lists containing triangles.
     '''
 
@@ -45,6 +48,7 @@ def mesh_linked_uv_islands(mesh: 'bpy.types.Mesh') -> list:
 
     :param mesh: the mesh used to group with.
     :type mesh: 'bpy.types.Mesh'
+    :rtype: list
     :return: lists of lists containing polygon indices
     '''
 
@@ -75,6 +79,7 @@ def triangle_random_points(
 
     :param loop_triangles: list of the triangles to generate points on.
     :type loop_triangles: typing.List['bpy.types.MeshLoopTriangle']
+    :rtype: list
     :return: list of random points over all triangles.
     '''
 
