@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
     bl_idname = None
@@ -60,6 +58,24 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -126,7 +142,7 @@ class BUILTIN_KSI_Available(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, context):
         ''' 
 
         '''
@@ -215,6 +231,24 @@ class BUILTIN_KSI_BendyBones(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -358,7 +392,7 @@ class BUILTIN_KSI_DeltaLocation(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _context, ks, data):
         ''' 
 
         '''
@@ -370,6 +404,24 @@ class BUILTIN_KSI_DeltaLocation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -513,7 +565,7 @@ class BUILTIN_KSI_DeltaRotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _context, ks, data):
         ''' 
 
         '''
@@ -525,6 +577,24 @@ class BUILTIN_KSI_DeltaRotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -668,7 +738,7 @@ class BUILTIN_KSI_DeltaScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, data):
+    def generate(self, _context, ks, data):
         ''' 
 
         '''
@@ -680,6 +750,24 @@ class BUILTIN_KSI_DeltaScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -835,6 +923,24 @@ class BUILTIN_KSI_LocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -993,6 +1099,200 @@ class BUILTIN_KSI_LocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def iterator(self, ksi, context, ks):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, ksi, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class BUILTIN_KSI_LocRotScaleCProp(bpy_types.KeyingSetInfo):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def generate(self, context, ks, data):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1148,6 +1448,24 @@ class BUILTIN_KSI_LocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1306,6 +1624,24 @@ class BUILTIN_KSI_Location(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1461,6 +1797,24 @@ class BUILTIN_KSI_RotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1619,6 +1973,24 @@ class BUILTIN_KSI_Rotation(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1777,6 +2149,24 @@ class BUILTIN_KSI_Scaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1935,6 +2325,24 @@ class BUILTIN_KSI_VisualLoc(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2093,6 +2501,24 @@ class BUILTIN_KSI_VisualLocRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2251,6 +2677,24 @@ class BUILTIN_KSI_VisualLocRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2409,6 +2853,24 @@ class BUILTIN_KSI_VisualLocScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2567,6 +3029,24 @@ class BUILTIN_KSI_VisualRot(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2725,6 +3205,24 @@ class BUILTIN_KSI_VisualRotScale(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2883,6 +3381,24 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2986,7 +3502,72 @@ class BUILTIN_KSI_VisualScaling(bpy_types.KeyingSetInfo):
         pass
 
 
-class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
+class WholeCharacterMixin:
+    badBonePrefixes = None
+    ''' '''
+
+    def addProp(self, ks, bone, prop, index, use_groups):
+        ''' 
+
+        '''
+        pass
+
+    def doBBone(self, context, ks, pchan):
+        ''' 
+
+        '''
+        pass
+
+    def doCustomProps(self, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def doLoc(self, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def doRot3d(self, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def doRot4d(self, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def doScale(self, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def generate(self, context, ks, bone):
+        ''' 
+
+        '''
+        pass
+
+    def iterator(self, context, ks):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class BUILTIN_KSI_WholeCharacter(WholeCharacterMixin, bpy_types.KeyingSetInfo):
     badBonePrefixes = None
     ''' '''
 
@@ -3002,7 +3583,7 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
     id_data = None
     ''' '''
 
-    def addProp(self, ksi, ks, bone, prop, index, use_groups):
+    def addProp(self, ks, bone, prop, index, use_groups):
         ''' 
 
         '''
@@ -3026,37 +3607,37 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def doBBone(self, ksi, context, ks, pchan):
+    def doBBone(self, context, ks, pchan):
         ''' 
 
         '''
         pass
 
-    def doCustomProps(self, ksi, ks, bone):
+    def doCustomProps(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doLoc(self, ksi, ks, bone):
+    def doLoc(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doRot3d(self, ksi, ks, bone):
+    def doRot3d(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doRot4d(self, ksi, ks, bone):
+    def doRot4d(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doScale(self, ksi, ks, bone):
+    def doScale(self, ks, bone):
         ''' 
 
         '''
@@ -3074,7 +3655,7 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, bone):
+    def generate(self, context, ks, bone):
         ''' 
 
         '''
@@ -3086,6 +3667,24 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3116,7 +3715,7 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def iterator(self, ksi, context, ks):
+    def iterator(self, context, ks):
         ''' 
 
         '''
@@ -3152,7 +3751,7 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, context):
         ''' 
 
         '''
@@ -3189,7 +3788,11 @@ class BUILTIN_KSI_WholeCharacter(bpy_types.KeyingSetInfo):
         pass
 
 
-class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
+class BUILTIN_KSI_WholeCharacterSelected(WholeCharacterMixin,
+                                         bpy_types.KeyingSetInfo):
+    badBonePrefixes = None
+    ''' '''
+
     bl_idname = None
     ''' '''
 
@@ -3202,7 +3805,7 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
     id_data = None
     ''' '''
 
-    def addProp(self, ksi, ks, bone, prop, index, use_groups):
+    def addProp(self, ks, bone, prop, index, use_groups):
         ''' 
 
         '''
@@ -3226,37 +3829,37 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def doBBone(self, ksi, context, ks, pchan):
+    def doBBone(self, context, ks, pchan):
         ''' 
 
         '''
         pass
 
-    def doCustomProps(self, ksi, ks, bone):
+    def doCustomProps(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doLoc(self, ksi, ks, bone):
+    def doLoc(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doRot3d(self, ksi, ks, bone):
+    def doRot3d(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doRot4d(self, ksi, ks, bone):
+    def doRot4d(self, ks, bone):
         ''' 
 
         '''
         pass
 
-    def doScale(self, ksi, ks, bone):
+    def doScale(self, ks, bone):
         ''' 
 
         '''
@@ -3274,7 +3877,7 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def generate(self, ksi, context, ks, bone):
+    def generate(self, context, ks, bone):
         ''' 
 
         '''
@@ -3286,6 +3889,24 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3316,7 +3937,7 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def iterator(self, ksi, context, ks):
+    def iterator(self, context, ks):
         ''' 
 
         '''
@@ -3352,7 +3973,7 @@ class BUILTIN_KSI_WholeCharacterSelected(bpy_types.KeyingSetInfo):
         '''
         pass
 
-    def poll(self, ksi, context):
+    def poll(self, context):
         ''' 
 
         '''
