@@ -1,8 +1,6 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def RKS_GEN_available(_ksi, _context, ks, data):
     ''' 
@@ -20,6 +18,14 @@ def RKS_GEN_bendy_bones(_ksi, _context, ks, data):
     pass
 
 
+def RKS_GEN_custom_props(_ksi, _context, ks, data):
+    ''' 
+
+    '''
+
+    pass
+
+
 def RKS_GEN_location(_ksi, _context, ks, data):
     ''' 
 
